# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import backoff_pb2 as envoy_dot_api_dot_v2_dot_core_dot_backoff__pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from envoy.type import semantic_version_pb2 as envoy_dot_type_dot_semantic__version__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2

from envoy.api.v2.core.socket_option_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/api/v2/core/base.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1f\x65nvoy/api/v2/core/backoff.proto\x1a envoy/api/v2/core/http_uri.proto\x1a\x18\x65nvoy/type/percent.proto\x1a!envoy/type/semantic_version.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\x1a%envoy/api/v2/core/socket_option.proto\":\n\x08Locality\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x10\n\x08sub_zone\x18\x03 \x01(\t\"g\n\x0c\x42uildVersion\x12,\n\x07version\x18\x01 \x01(\x0b\x32\x1b.envoy.type.SemanticVersion\x12)\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x88\x01\n\tExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x17\n\x0ftype_descriptor\x18\x03 \x01(\t\x12\x30\n\x07version\x18\x04 \x01(\x0b\x32\x1f.envoy.api.v2.core.BuildVersion\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\"\xb3\x03\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x08locality\x18\x04 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x19\n\rbuild_version\x18\x05 \x01(\tB\x02\x18\x01\x12\x17\n\x0fuser_agent_name\x18\x06 \x01(\t\x12\x1c\n\x12user_agent_version\x18\x07 \x01(\tH\x00\x12\x43\n\x18user_agent_build_version\x18\x08 \x01(\x0b\x32\x1f.envoy.api.v2.core.BuildVersionH\x00\x12\x30\n\nextensions\x18\t \x03(\x0b\x32\x1c.envoy.api.v2.core.Extension\x12\x17\n\x0f\x63lient_features\x18\n \x03(\t\x12\x37\n\x13listening_addresses\x18\x0b \x03(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x19\n\x17user_agent_version_type\"\xa4\x01\n\x08Metadata\x12H\n\x0f\x66ilter_metadata\x18\x01 \x03(\x0b\x32/.envoy.api.v2.core.Metadata.FilterMetadataEntry\x1aN\n\x13\x46ilterMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"D\n\rRuntimeUInt32\x12\x15\n\rdefault_value\x18\x02 \x01(\r\x12\x1c\n\x0bruntime_key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"D\n\rRuntimeDouble\x12\x15\n\rdefault_value\x18\x01 \x01(\x01\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"o\n\x12RuntimeFeatureFlag\x12;\n\rdefault_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"M\n\x0bHeaderValue\x12\x1e\n\x03key\x18\x01 \x01(\tB\x11\xfa\x42\x0er\x0c \x01(\x80\x80\x01\xc0\x01\x01\xc8\x01\x00\x12\x1e\n\x05value\x18\x02 \x01(\tB\x0f\xfa\x42\x0cr\n(\x80\x80\x01\xc0\x01\x02\xc8\x01\x00\"y\n\x11HeaderValueOption\x12\x38\n\x06header\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.HeaderValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12*\n\x06\x61ppend\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"<\n\tHeaderMap\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"~\n\nDataSource\x12\x1b\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x1f\n\x0cinline_bytes\x18\x02 \x01(\x0c\x42\x07\xfa\x42\x04z\x02\x10\x01H\x00\x12 \n\rinline_string\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x42\x10\n\tspecifier\x12\x03\xf8\x42\x01\"|\n\x0bRetryPolicy\x12:\n\x0eretry_back_off\x18\x01 \x01(\x0b\x32\".envoy.api.v2.core.BackoffStrategy\x12\x31\n\x0bnum_retries\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\x99\x01\n\x10RemoteDataSource\x12\x36\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUriB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x17\n\x06sha256\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x0cretry_policy\x18\x03 \x01(\x0b\x32\x1e.envoy.api.v2.core.RetryPolicy\"\x8a\x01\n\x0f\x41syncDataSource\x12.\n\x05local\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceH\x00\x12\x35\n\x06remote\x18\x02 \x01(\x0b\x32#.envoy.api.v2.core.RemoteDataSourceH\x00\x42\x10\n\tspecifier\x12\x03\xf8\x42\x01\"\x94\x01\n\x0fTransportSocket\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"o\n\x18RuntimeFractionalPercent\x12>\n\rdefault_value\x18\x01 \x01(\x0b\x32\x1d.envoy.type.FractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x13\n\x0bruntime_key\x18\x02 \x01(\t\"\"\n\x0c\x43ontrolPlane\x12\x12\n\nidentifier\x18\x01 \x01(\t*(\n\x0fRoutingPriority\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04HIGH\x10\x01*\x89\x01\n\rRequestMethod\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x07\n\x03GET\x10\x01\x12\x08\n\x04HEAD\x10\x02\x12\x08\n\x04POST\x10\x03\x12\x07\n\x03PUT\x10\x04\x12\n\n\x06\x44\x45LETE\x10\x05\x12\x0b\n\x07\x43ONNECT\x10\x06\x12\x0b\n\x07OPTIONS\x10\x07\x12\t\n\x05TRACE\x10\x08\x12\t\n\x05PATCH\x10\t*>\n\x10TrafficDirection\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07INBOUND\x10\x01\x12\x0c\n\x08OUTBOUND\x10\x02\x42\x8c\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\tBaseProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x0b\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.base_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\tBaseProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _NODE.fields_by_name['build_version']._options = None
  _NODE.fields_by_name['build_version']._serialized_options = b'\030\001'
  _METADATA_FILTERMETADATAENTRY._options = None
  _METADATA_FILTERMETADATAENTRY._serialized_options = b'8\001'
  _RUNTIMEUINT32.fields_by_name['runtime_key']._options = None
  _RUNTIMEUINT32.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _RUNTIMEDOUBLE.fields_by_name['runtime_key']._options = None
  _RUNTIMEDOUBLE.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _RUNTIMEFEATUREFLAG.fields_by_name['default_value']._options = None
  _RUNTIMEFEATUREFLAG.fields_by_name['default_value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RUNTIMEFEATUREFLAG.fields_by_name['runtime_key']._options = None
  _RUNTIMEFEATUREFLAG.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _HEADERVALUE.fields_by_name['key']._options = None
  _HEADERVALUE.fields_by_name['key']._serialized_options = b'\372B\016r\014 \001(\200\200\001\300\001\001\310\001\000'
  _HEADERVALUE.fields_by_name['value']._options = None
  _HEADERVALUE.fields_by_name['value']._serialized_options = b'\372B\014r\n(\200\200\001\300\001\002\310\001\000'
  _HEADERVALUEOPTION.fields_by_name['header']._options = None
  _HEADERVALUEOPTION.fields_by_name['header']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DATASOURCE.oneofs_by_name['specifier']._options = None
  _DATASOURCE.oneofs_by_name['specifier']._serialized_options = b'\370B\001'
  _DATASOURCE.fields_by_name['filename']._options = None
  _DATASOURCE.fields_by_name['filename']._serialized_options = b'\372B\004r\002 \001'
  _DATASOURCE.fields_by_name['inline_bytes']._options = None
  _DATASOURCE.fields_by_name['inline_bytes']._serialized_options = b'\372B\004z\002\020\001'
  _DATASOURCE.fields_by_name['inline_string']._options = None
  _DATASOURCE.fields_by_name['inline_string']._serialized_options = b'\372B\004r\002 \001'
  _REMOTEDATASOURCE.fields_by_name['http_uri']._options = None
  _REMOTEDATASOURCE.fields_by_name['http_uri']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REMOTEDATASOURCE.fields_by_name['sha256']._options = None
  _REMOTEDATASOURCE.fields_by_name['sha256']._serialized_options = b'\372B\004r\002 \001'
  _ASYNCDATASOURCE.oneofs_by_name['specifier']._options = None
  _ASYNCDATASOURCE.oneofs_by_name['specifier']._serialized_options = b'\370B\001'
  _TRANSPORTSOCKET.fields_by_name['name']._options = None
  _TRANSPORTSOCKET.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _TRANSPORTSOCKET.fields_by_name['config']._options = None
  _TRANSPORTSOCKET.fields_by_name['config']._serialized_options = b'\030\001'
  _RUNTIMEFRACTIONALPERCENT.fields_by_name['default_value']._options = None
  _RUNTIMEFRACTIONALPERCENT.fields_by_name['default_value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_ROUTINGPRIORITY']._serialized_start=2705
  _globals['_ROUTINGPRIORITY']._serialized_end=2745
  _globals['_REQUESTMETHOD']._serialized_start=2748
  _globals['_REQUESTMETHOD']._serialized_end=2885
  _globals['_TRAFFICDIRECTION']._serialized_start=2887
  _globals['_TRAFFICDIRECTION']._serialized_end=2949
  _globals['_LOCALITY']._serialized_start=428
  _globals['_LOCALITY']._serialized_end=486
  _globals['_BUILDVERSION']._serialized_start=488
  _globals['_BUILDVERSION']._serialized_end=591
  _globals['_EXTENSION']._serialized_start=594
  _globals['_EXTENSION']._serialized_end=730
  _globals['_NODE']._serialized_start=733
  _globals['_NODE']._serialized_end=1168
  _globals['_METADATA']._serialized_start=1171
  _globals['_METADATA']._serialized_end=1335
  _globals['_METADATA_FILTERMETADATAENTRY']._serialized_start=1257
  _globals['_METADATA_FILTERMETADATAENTRY']._serialized_end=1335
  _globals['_RUNTIMEUINT32']._serialized_start=1337
  _globals['_RUNTIMEUINT32']._serialized_end=1405
  _globals['_RUNTIMEDOUBLE']._serialized_start=1407
  _globals['_RUNTIMEDOUBLE']._serialized_end=1475
  _globals['_RUNTIMEFEATUREFLAG']._serialized_start=1477
  _globals['_RUNTIMEFEATUREFLAG']._serialized_end=1588
  _globals['_HEADERVALUE']._serialized_start=1590
  _globals['_HEADERVALUE']._serialized_end=1667
  _globals['_HEADERVALUEOPTION']._serialized_start=1669
  _globals['_HEADERVALUEOPTION']._serialized_end=1790
  _globals['_HEADERMAP']._serialized_start=1792
  _globals['_HEADERMAP']._serialized_end=1852
  _globals['_DATASOURCE']._serialized_start=1854
  _globals['_DATASOURCE']._serialized_end=1980
  _globals['_RETRYPOLICY']._serialized_start=1982
  _globals['_RETRYPOLICY']._serialized_end=2106
  _globals['_REMOTEDATASOURCE']._serialized_start=2109
  _globals['_REMOTEDATASOURCE']._serialized_end=2262
  _globals['_ASYNCDATASOURCE']._serialized_start=2265
  _globals['_ASYNCDATASOURCE']._serialized_end=2403
  _globals['_TRANSPORTSOCKET']._serialized_start=2406
  _globals['_TRANSPORTSOCKET']._serialized_end=2554
  _globals['_RUNTIMEFRACTIONALPERCENT']._serialized_start=2556
  _globals['_RUNTIMEFRACTIONALPERCENT']._serialized_end=2667
  _globals['_CONTROLPLANE']._serialized_start=2669
  _globals['_CONTROLPLANE']._serialized_end=2703
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v3/attribute_context.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/service/auth/v3/attribute_context.proto\x12\x15\x65nvoy.service.auth.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xbe\x0b\n\x10\x41ttributeContext\x12<\n\x06source\x18\x01 \x01(\x0b\x32,.envoy.service.auth.v3.AttributeContext.Peer\x12\x41\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32,.envoy.service.auth.v3.AttributeContext.Peer\x12@\n\x07request\x18\x04 \x01(\x0b\x32/.envoy.service.auth.v3.AttributeContext.Request\x12Z\n\x12\x63ontext_extensions\x18\n \x03(\x0b\x32>.envoy.service.auth.v3.AttributeContext.ContextExtensionsEntry\x12\x38\n\x10metadata_context\x18\x0b \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12>\n\x16route_metadata_context\x18\r \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12G\n\x0btls_session\x18\x0c \x01(\x0b\x32\x32.envoy.service.auth.v3.AttributeContext.TLSSession\x1a\x9c\x02\n\x04Peer\x12.\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12\x0f\n\x07service\x18\x02 \x01(\t\x12H\n\x06labels\x18\x03 \x03(\x0b\x32\x38.envoy.service.auth.v3.AttributeContext.Peer.LabelsEntry\x12\x11\n\tprincipal\x18\x04 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:2\x9a\xc5\x88\x1e-\n+envoy.service.auth.v2.AttributeContext.Peer\x1a\xad\x01\n\x07Request\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x04http\x18\x02 \x01(\x0b\x32\x33.envoy.service.auth.v3.AttributeContext.HttpRequest:5\x9a\xc5\x88\x1e\x30\n.envoy.service.auth.v2.AttributeContext.Request\x1a\xf4\x02\n\x0bHttpRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12Q\n\x07headers\x18\x03 \x03(\x0b\x32@.envoy.service.auth.v3.AttributeContext.HttpRequest.HeadersEntry\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\x0e\n\x06scheme\x18\x06 \x01(\t\x12\r\n\x05query\x18\x07 \x01(\t\x12\x10\n\x08\x66ragment\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x03\x12\x10\n\x08protocol\x18\n \x01(\t\x12\x0c\n\x04\x62ody\x18\x0b \x01(\t\x12\x10\n\x08raw_body\x18\x0c \x01(\x0c\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:9\x9a\xc5\x88\x1e\x34\n2envoy.service.auth.v2.AttributeContext.HttpRequest\x1a\x19\n\nTLSSession\x12\x0b\n\x03sni\x18\x01 \x01(\t\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:-\x9a\xc5\x88\x1e(\n&envoy.service.auth.v2.AttributeContextB\x8b\x01\n#io.envoyproxy.envoy.service.auth.v3B\x15\x41ttributeContextProtoP\x01ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v3;authv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v3.attribute_context_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.service.auth.v3B\025AttributeContextProtoP\001ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v3;authv3\272\200\310\321\006\002\020\002'
  _ATTRIBUTECONTEXT_PEER_LABELSENTRY._options = None
  _ATTRIBUTECONTEXT_PEER_LABELSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT_PEER._options = None
  _ATTRIBUTECONTEXT_PEER._serialized_options = b'\232\305\210\036-\n+envoy.service.auth.v2.AttributeContext.Peer'
  _ATTRIBUTECONTEXT_REQUEST._options = None
  _ATTRIBUTECONTEXT_REQUEST._serialized_options = b'\232\305\210\0360\n.envoy.service.auth.v2.AttributeContext.Request'
  _ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY._options = None
  _ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT_HTTPREQUEST._options = None
  _ATTRIBUTECONTEXT_HTTPREQUEST._serialized_options = b'\232\305\210\0364\n2envoy.service.auth.v2.AttributeContext.HttpRequest'
  _ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY._options = None
  _ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY._serialized_options = b'8\001'
  _ATTRIBUTECONTEXT._options = None
  _ATTRIBUTECONTEXT._serialized_options = b'\232\305\210\036(\n&envoy.service.auth.v2.AttributeContext'
  _globals['_ATTRIBUTECONTEXT']._serialized_start=241
  _globals['_ATTRIBUTECONTEXT']._serialized_end=1711
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_start=744
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_end=1028
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_start=931
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_end=976
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_start=1031
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_end=1204
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST']._serialized_start=1207
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST']._serialized_end=1579
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_start=1474
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_end=1520
  _globals['_ATTRIBUTECONTEXT_TLSSESSION']._serialized_start=1581
  _globals['_ATTRIBUTECONTEXT_TLSSESSION']._serialized_end=1606
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_start=1608
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_end=1664
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v3/outlier_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/config/cluster/v3/outlier_detection.proto\x12\x17\x65nvoy.config.cluster.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9a\r\n\x10OutlierDetection\x12\x35\n\x0f\x63onsecutive_5xx\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12\x62\x61se_ejection_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14max_ejection_percent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12H\n\x19\x65nforcing_consecutive_5xx\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x45\n\x16\x65nforcing_success_rate\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12@\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19success_rate_stdev_factor\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1b\x63onsecutive_gateway_failure\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12T\n%enforcing_consecutive_gateway_failure\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12*\n\"split_external_local_origin_errors\x18\x0c \x01(\x08\x12\x46\n consecutive_local_origin_failure\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Y\n*enforcing_consecutive_local_origin_failure\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12R\n#enforcing_local_origin_success_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x66\x61ilure_percentage_threshold\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x65nforcing_failure_percentage\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12X\n)enforcing_failure_percentage_local_origin\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x46\n failure_percentage_minimum_hosts\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n!failure_percentage_request_volume\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11max_ejection_time\x18\x15 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12;\n\x18max_ejection_time_jitter\x18\x16 \x01(\x0b\x32\x19.google.protobuf.Duration\x12O\n+successful_active_health_check_uneject_host\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.cluster.OutlierDetectionB\x92\x01\n%io.envoyproxy.envoy.config.cluster.v3B\x15OutlierDetectionProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.v3.outlier_detection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.cluster.v3B\025OutlierDetectionProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _OUTLIERDETECTION.fields_by_name['interval']._options = None
  _OUTLIERDETECTION.fields_by_name['interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _OUTLIERDETECTION.fields_by_name['base_ejection_time']._options = None
  _OUTLIERDETECTION.fields_by_name['base_ejection_time']._serialized_options = b'\372B\005\252\001\002*\000'
  _OUTLIERDETECTION.fields_by_name['max_ejection_percent']._options = None
  _OUTLIERDETECTION.fields_by_name['max_ejection_percent']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_success_rate']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['failure_percentage_threshold']._options = None
  _OUTLIERDETECTION.fields_by_name['failure_percentage_threshold']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['max_ejection_time']._options = None
  _OUTLIERDETECTION.fields_by_name['max_ejection_time']._serialized_options = b'\372B\005\252\001\002*\000'
  _OUTLIERDETECTION._options = None
  _OUTLIERDETECTION._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.cluster.OutlierDetection'
  _globals['_OUTLIERDETECTION']._serialized_start=232
  _globals['_OUTLIERDETECTION']._serialized_end=1922
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/system_parameter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!google/api/system_parameter.proto\x12\ngoogle.api\"B\n\x10SystemParameters\x12.\n\x05rules\x18\x01 \x03(\x0b\x32\x1f.google.api.SystemParameterRule\"X\n\x13SystemParameterRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12/\n\nparameters\x18\x02 \x03(\x0b\x32\x1b.google.api.SystemParameter\"Q\n\x0fSystemParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bhttp_header\x18\x02 \x01(\t\x12\x1b\n\x13url_query_parameter\x18\x03 \x01(\tBv\n\x0e\x63om.google.apiB\x14SystemParameterProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.system_parameter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\024SystemParameterProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_SYSTEMPARAMETERS']._serialized_start=49
  _globals['_SYSTEMPARAMETERS']._serialized_end=115
  _globals['_SYSTEMPARAMETERRULE']._serialized_start=117
  _globals['_SYSTEMPARAMETERRULE']._serialized_end=205
  _globals['_SYSTEMPARAMETER']._serialized_start=207
  _globals['_SYSTEMPARAMETER']._serialized_end=288
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/tracing/v2/custom_tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.metadata.v2 import metadata_pb2 as envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/type/tracing/v2/custom_tag.proto\x12\x15\x65nvoy.type.tracing.v2\x1a%envoy/type/metadata/v2/metadata.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe3\x04\n\tCustomTag\x12\x14\n\x03tag\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12;\n\x07literal\x18\x02 \x01(\x0b\x32(.envoy.type.tracing.v2.CustomTag.LiteralH\x00\x12\x43\n\x0b\x65nvironment\x18\x03 \x01(\x0b\x32,.envoy.type.tracing.v2.CustomTag.EnvironmentH\x00\x12\x41\n\x0erequest_header\x18\x04 \x01(\x0b\x32\'.envoy.type.tracing.v2.CustomTag.HeaderH\x00\x12=\n\x08metadata\x18\x05 \x01(\x0b\x32).envoy.type.tracing.v2.CustomTag.MetadataH\x00\x1a!\n\x07Literal\x12\x16\n\x05value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a;\n\x0b\x45nvironment\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x15\n\rdefault_value\x18\x02 \x01(\t\x1a<\n\x06Header\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x12\x15\n\rdefault_value\x18\x02 \x01(\t\x1a\x90\x01\n\x08Metadata\x12\x32\n\x04kind\x18\x01 \x01(\x0b\x32$.envoy.type.metadata.v2.MetadataKind\x12\x39\n\x0cmetadata_key\x18\x02 \x01(\x0b\x32#.envoy.type.metadata.v2.MetadataKey\x12\x15\n\rdefault_value\x18\x03 \x01(\tB\x0b\n\x04type\x12\x03\xf8\x42\x01\x42\x87\x01\n#io.envoyproxy.envoy.type.tracing.v2B\x0e\x43ustomTagProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/tracing/v2;tracingv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.tracing.v2.custom_tag_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.tracing.v2B\016CustomTagProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/tracing/v2;tracingv2\272\200\310\321\006\002\020\001'
  _CUSTOMTAG_LITERAL.fields_by_name['value']._options = None
  _CUSTOMTAG_LITERAL.fields_by_name['value']._serialized_options = b'\372B\004r\002 \001'
  _CUSTOMTAG_ENVIRONMENT.fields_by_name['name']._options = None
  _CUSTOMTAG_ENVIRONMENT.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _CUSTOMTAG_HEADER.fields_by_name['name']._options = None
  _CUSTOMTAG_HEADER.fields_by_name['name']._serialized_options = b'\372B\nr\010 \001\300\001\001\310\001\000'
  _CUSTOMTAG.oneofs_by_name['type']._options = None
  _CUSTOMTAG.oneofs_by_name['type']._serialized_options = b'\370B\001'
  _CUSTOMTAG.fields_by_name['tag']._options = None
  _CUSTOMTAG.fields_by_name['tag']._serialized_options = b'\372B\004r\002 \001'
  _globals['_CUSTOMTAG']._serialized_start=161
  _globals['_CUSTOMTAG']._serialized_end=772
  _globals['_CUSTOMTAG_LITERAL']._serialized_start=456
  _globals['_CUSTOMTAG_LITERAL']._serialized_end=489
  _globals['_CUSTOMTAG_ENVIRONMENT']._serialized_start=491
  _globals['_CUSTOMTAG_ENVIRONMENT']._serialized_end=550
  _globals['_CUSTOMTAG_HEADER']._serialized_start=552
  _globals['_CUSTOMTAG_HEADER']._serialized_end=612
  _globals['_CUSTOMTAG_METADATA']._serialized_start=615
  _globals['_CUSTOMTAG_METADATA']._serialized_end=759
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/geoip/v3/geoip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/geoip/v3/geoip.proto\x12&envoy.extensions.filters.http.geoip.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc7\x01\n\x05Geoip\x12K\n\nxff_config\x18\x01 \x01(\x0b\x32\x37.envoy.extensions.filters.http.geoip.v3.Geoip.XffConfig\x12\x46\n\x08provider\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a)\n\tXffConfig\x12\x1c\n\x14xff_num_trusted_hops\x18\x01 \x01(\rB\xab\x01\n4io.envoyproxy.envoy.extensions.filters.http.geoip.v3B\nGeoipProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/geoip/v3;geoipv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.geoip.v3.geoip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.geoip.v3B\nGeoipProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/geoip/v3;geoipv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _GEOIP.fields_by_name['provider']._options = None
  _GEOIP.fields_by_name['provider']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_GEOIP']._serialized_start=222
  _globals['_GEOIP']._serialized_end=421
  _globals['_GEOIP_XFFCONFIG']._serialized_start=380
  _globals['_GEOIP_XFFCONFIG']._serialized_end=421
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/async_files/v3/async_file_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/common/async_files/v3/async_file_manager.proto\x12&envoy.extensions.common.async_files.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc9\x01\n\x16\x41syncFileManagerConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12`\n\x0bthread_pool\x18\x02 \x01(\x0b\x32I.envoy.extensions.common.async_files.v3.AsyncFileManagerConfig.ThreadPoolH\x00\x1a,\n\nThreadPool\x12\x1e\n\x0cthread_count\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x18\x80\x08\x42\x13\n\x0cmanager_type\x12\x03\xf8\x42\x01\x42\xbc\x01\n4io.envoyproxy.envoy.extensions.common.async_files.v3B\x15\x41syncFileManagerProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/common/async_files/v3;async_filesv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.async_files.v3.async_file_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.common.async_files.v3B\025AsyncFileManagerProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/common/async_files/v3;async_filesv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _ASYNCFILEMANAGERCONFIG_THREADPOOL.fields_by_name['thread_count']._options = None
  _ASYNCFILEMANAGERCONFIG_THREADPOOL.fields_by_name['thread_count']._serialized_options = b'\372B\005*\003\030\200\010'
  _ASYNCFILEMANAGERCONFIG.oneofs_by_name['manager_type']._options = None
  _ASYNCFILEMANAGERCONFIG.oneofs_by_name['manager_type']._serialized_options = b'\370B\001'
  _globals['_ASYNCFILEMANAGERCONFIG']._serialized_start=197
  _globals['_ASYNCFILEMANAGERCONFIG']._serialized_end=398
  _globals['_ASYNCFILEMANAGERCONFIG_THREADPOOL']._serialized_start=333
  _globals['_ASYNCFILEMANAGERCONFIG_THREADPOOL']._serialized_end=377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/stateful_session/header/v3/header.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=envoy/extensions/http/stateful_session/header/v3/header.proto\x12\x30\x65nvoy.extensions.http.stateful_session.header.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"0\n\x17HeaderBasedSessionState\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xb9\x01\n>io.envoyproxy.envoy.extensions.http.stateful_session.header.v3B\x0bHeaderProtoP\x01Z`github.com/envoyproxy/go-control-plane/envoy/extensions/http/stateful_session/header/v3;headerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.stateful_session.header.v3.header_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.http.stateful_session.header.v3B\013HeaderProtoP\001Z`github.com/envoyproxy/go-control-plane/envoy/extensions/http/stateful_session/header/v3;headerv3\272\200\310\321\006\002\020\002'
  _HEADERBASEDSESSIONSTATE.fields_by_name['name']._options = None
  _HEADERBASEDSESSIONSTATE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_HEADERBASEDSESSIONSTATE']._serialized_start=171
  _globals['_HEADERBASEDSESSIONSTATE']._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.common.ratelimit.v3 import ratelimit_pb2 as envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto\x12\x30\x65nvoy.extensions.filters.http.local_ratelimit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x34\x65nvoy/extensions/common/ratelimit/v3/ratelimit.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xb9\x07\n\x0eLocalRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12)\n\x06status\x18\x02 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12\x30\n\x0ctoken_bucket\x18\x03 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucket\x12\x46\n\x0e\x66ilter_enabled\x18\x04 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12G\n\x0f\x66ilter_enforced\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12\x63\n(request_headers_to_add_when_not_enforced\x18\n \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\x12R\n\x17response_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\x12S\n\x0b\x64\x65scriptors\x18\x08 \x03(\x0b\x32>.envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor\x12\x16\n\x05stage\x18\t \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12\x32\n*local_rate_limit_per_downstream_connection\x18\x0b \x01(\x08\x12o\n\x1a\x65nable_x_ratelimit_headers\x18\x0c \x01(\x0e\x32\x41.envoy.extensions.common.ratelimit.v3.XRateLimitHeadersRFCVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12[\n\x0evh_rate_limits\x18\r \x01(\x0e\x32\x39.envoy.extensions.common.ratelimit.v3.VhRateLimitsOptionsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n#always_consume_default_token_bucket\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\"rate_limited_as_resource_exhausted\x18\x0f \x01(\x08\x42\xca\x01\n>io.envoyproxy.envoy.extensions.filters.http.local_ratelimit.v3B\x13LocalRateLimitProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/local_ratelimit/v3;local_ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.local_ratelimit.v3.local_rate_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.local_ratelimit.v3B\023LocalRateLimitProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/local_ratelimit/v3;local_ratelimitv3\272\200\310\321\006\002\020\002'
  _LOCALRATELIMIT.fields_by_name['stat_prefix']._options = None
  _LOCALRATELIMIT.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _LOCALRATELIMIT.fields_by_name['request_headers_to_add_when_not_enforced']._options = None
  _LOCALRATELIMIT.fields_by_name['request_headers_to_add_when_not_enforced']._serialized_options = b'\372B\005\222\001\002\020\n'
  _LOCALRATELIMIT.fields_by_name['response_headers_to_add']._options = None
  _LOCALRATELIMIT.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\005\222\001\002\020\n'
  _LOCALRATELIMIT.fields_by_name['stage']._options = None
  _LOCALRATELIMIT.fields_by_name['stage']._serialized_options = b'\372B\004*\002\030\n'
  _LOCALRATELIMIT.fields_by_name['enable_x_ratelimit_headers']._options = None
  _LOCALRATELIMIT.fields_by_name['enable_x_ratelimit_headers']._serialized_options = b'\372B\005\202\001\002\020\001'
  _LOCALRATELIMIT.fields_by_name['vh_rate_limits']._options = None
  _LOCALRATELIMIT.fields_by_name['vh_rate_limits']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_LOCALRATELIMIT']._serialized_start=368
  _globals['_LOCALRATELIMIT']._serialized_end=1321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/config/filter/http/aws_lambda/v2alpha/aws_lambda.proto\x12+envoy.config.filter.http.aws_lambda.v2alpha\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd7\x01\n\x06\x43onfig\x12\x14\n\x03\x61rn\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\x13payload_passthrough\x18\x02 \x01(\x08\x12\x65\n\x0finvocation_mode\x18\x03 \x01(\x0e\x32\x42.envoy.config.filter.http.aws_lambda.v2alpha.Config.InvocationModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"3\n\x0eInvocationMode\x12\x0f\n\x0bSYNCHRONOUS\x10\x00\x12\x10\n\x0c\x41SYNCHRONOUS\x10\x01\"\\\n\x0ePerRouteConfig\x12J\n\rinvoke_config\x18\x01 \x01(\x0b\x32\x33.envoy.config.filter.http.aws_lambda.v2alpha.ConfigB\xde\x01\n9io.envoyproxy.envoy.config.filter.http.aws_lambda.v2alphaB\x0e\x41wsLambdaProtoP\x01ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/aws_lambda/v2alpha\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.aws_lambda.v3\xba\x80\xc8\xd1\x06\x04\x08\x01\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.aws_lambda.v2alpha.aws_lambda_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9io.envoyproxy.envoy.config.filter.http.aws_lambda.v2alphaB\016AwsLambdaProtoP\001ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/aws_lambda/v2alpha\362\230\376\217\005-\022+envoy.extensions.filters.http.aws_lambda.v3\272\200\310\321\006\004\010\001\020\001'
  _CONFIG.fields_by_name['arn']._options = None
  _CONFIG.fields_by_name['arn']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIG.fields_by_name['invocation_mode']._options = None
  _CONFIG.fields_by_name['invocation_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CONFIG']._serialized_start=198
  _globals['_CONFIG']._serialized_end=413
  _globals['_CONFIG_INVOCATIONMODE']._serialized_start=362
  _globals['_CONFIG_INVOCATIONMODE']._serialized_end=413
  _globals['_PERROUTECONFIG']._serialized_start=415
  _globals['_PERROUTECONFIG']._serialized_end=507
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/checked.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/api/expr/v1alpha1/checked.proto\x12\x18google.api.expr.v1alpha1\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xb6\x03\n\x0b\x43heckedExpr\x12N\n\rreference_map\x18\x02 \x03(\x0b\x32\x37.google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntry\x12\x44\n\x08type_map\x18\x03 \x03(\x0b\x32\x32.google.api.expr.v1alpha1.CheckedExpr.TypeMapEntry\x12\x39\n\x0bsource_info\x18\x05 \x01(\x0b\x32$.google.api.expr.v1alpha1.SourceInfo\x12,\n\x04\x65xpr\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x1aX\n\x11ReferenceMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.google.api.expr.v1alpha1.Reference:\x02\x38\x01\x1aN\n\x0cTypeMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type:\x02\x38\x01\"\x82\n\n\x04Type\x12%\n\x03\x64yn\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12*\n\x04null\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x41\n\tprimitive\x18\x03 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.PrimitiveTypeH\x00\x12?\n\x07wrapper\x18\x04 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.PrimitiveTypeH\x00\x12\x42\n\nwell_known\x18\x05 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.WellKnownTypeH\x00\x12<\n\tlist_type\x18\x06 \x01(\x0b\x32\'.google.api.expr.v1alpha1.Type.ListTypeH\x00\x12:\n\x08map_type\x18\x07 \x01(\x0b\x32&.google.api.expr.v1alpha1.Type.MapTypeH\x00\x12?\n\x08\x66unction\x18\x08 \x01(\x0b\x32+.google.api.expr.v1alpha1.Type.FunctionTypeH\x00\x12\x16\n\x0cmessage_type\x18\t \x01(\tH\x00\x12\x14\n\ntype_param\x18\n \x01(\tH\x00\x12.\n\x04type\x18\x0b \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeH\x00\x12\'\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x44\n\rabstract_type\x18\x0e \x01(\x0b\x32+.google.api.expr.v1alpha1.Type.AbstractTypeH\x00\x1a=\n\x08ListType\x12\x31\n\telem_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x1ao\n\x07MapType\x12\x30\n\x08key_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x32\n\nvalue_type\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x1av\n\x0c\x46unctionType\x12\x33\n\x0bresult_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x31\n\targ_types\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x1aU\n\x0c\x41\x62stractType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x0fparameter_types\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\"s\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\n\n\x06UINT64\x10\x03\x12\n\n\x06\x44OUBLE\x10\x04\x12\n\n\x06STRING\x10\x05\x12\t\n\x05\x42YTES\x10\x06\"V\n\rWellKnownType\x12\x1f\n\x1bWELL_KNOWN_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\r\n\tTIMESTAMP\x10\x02\x12\x0c\n\x08\x44URATION\x10\x03\x42\x0b\n\ttype_kind\"\xb9\x04\n\x04\x44\x65\x63l\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x05ident\x18\x02 \x01(\x0b\x32(.google.api.expr.v1alpha1.Decl.IdentDeclH\x00\x12?\n\x08\x66unction\x18\x03 \x01(\x0b\x32+.google.api.expr.v1alpha1.Decl.FunctionDeclH\x00\x1ay\n\tIdentDecl\x12,\n\x04type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".google.api.expr.v1alpha1.Constant\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x1a\x9e\x02\n\x0c\x46unctionDecl\x12G\n\toverloads\x18\x01 \x03(\x0b\x32\x34.google.api.expr.v1alpha1.Decl.FunctionDecl.Overload\x1a\xc4\x01\n\x08Overload\x12\x13\n\x0boverload_id\x18\x01 \x01(\t\x12.\n\x06params\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x13\n\x0btype_params\x18\x03 \x03(\t\x12\x33\n\x0bresult_type\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x1c\n\x14is_instance_function\x18\x05 \x01(\x08\x12\x0b\n\x03\x64oc\x18\x06 \x01(\tB\x0b\n\tdecl_kind\"a\n\tReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0boverload_id\x18\x03 \x03(\t\x12\x31\n\x05value\x18\x04 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantBl\n\x1c\x63om.google.api.expr.v1alpha1B\tDeclProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.checked_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\tDeclProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001'
  _CHECKEDEXPR_REFERENCEMAPENTRY._options = None
  _CHECKEDEXPR_REFERENCEMAPENTRY._serialized_options = b'8\001'
  _CHECKEDEXPR_TYPEMAPENTRY._options = None
  _CHECKEDEXPR_TYPEMAPENTRY._serialized_options = b'8\001'
  _globals['_CHECKEDEXPR']._serialized_start=167
  _globals['_CHECKEDEXPR']._serialized_end=605
  _globals['_CHECKEDEXPR_REFERENCEMAPENTRY']._serialized_start=437
  _globals['_CHECKEDEXPR_REFERENCEMAPENTRY']._serialized_end=525
  _globals['_CHECKEDEXPR_TYPEMAPENTRY']._serialized_start=527
  _globals['_CHECKEDEXPR_TYPEMAPENTRY']._serialized_end=605
  _globals['_TYPE']._serialized_start=608
  _globals['_TYPE']._serialized_end=1890
  _globals['_TYPE_LISTTYPE']._serialized_start=1291
  _globals['_TYPE_LISTTYPE']._serialized_end=1352
  _globals['_TYPE_MAPTYPE']._serialized_start=1354
  _globals['_TYPE_MAPTYPE']._serialized_end=1465
  _globals['_TYPE_FUNCTIONTYPE']._serialized_start=1467
  _globals['_TYPE_FUNCTIONTYPE']._serialized_end=1585
  _globals['_TYPE_ABSTRACTTYPE']._serialized_start=1587
  _globals['_TYPE_ABSTRACTTYPE']._serialized_end=1672
  _globals['_TYPE_PRIMITIVETYPE']._serialized_start=1674
  _globals['_TYPE_PRIMITIVETYPE']._serialized_end=1789
  _globals['_TYPE_WELLKNOWNTYPE']._serialized_start=1791
  _globals['_TYPE_WELLKNOWNTYPE']._serialized_end=1877
  _globals['_DECL']._serialized_start=1893
  _globals['_DECL']._serialized_end=2462
  _globals['_DECL_IDENTDECL']._serialized_start=2039
  _globals['_DECL_IDENTDECL']._serialized_end=2160
  _globals['_DECL_FUNCTIONDECL']._serialized_start=2163
  _globals['_DECL_FUNCTIONDECL']._serialized_end=2449
  _globals['_DECL_FUNCTIONDECL_OVERLOAD']._serialized_start=2253
  _globals['_DECL_FUNCTIONDECL_OVERLOAD']._serialized_end=2449
  _globals['_REFERENCE']._serialized_start=2464
  _globals['_REFERENCE']._serialized_end=2561
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/source_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgoogle/api/source_info.proto\x12\ngoogle.api\x1a\x19google/protobuf/any.proto\"8\n\nSourceInfo\x12*\n\x0csource_files\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyBq\n\x0e\x63om.google.apiB\x0fSourceInfoProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.source_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\017SourceInfoProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_SOURCEINFO']._serialized_start=71
  _globals['_SOURCEINFO']._serialized_end=127
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/string.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import regex_pb2 as envoy_dot_type_dot_matcher_dot_regex__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/type/matcher/string.proto\x12\x12\x65nvoy.type.matcher\x1a\x1e\x65nvoy/type/matcher/regex.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe6\x01\n\rStringMatcher\x12\x0f\n\x05\x65xact\x18\x01 \x01(\tH\x00\x12\x19\n\x06prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x19\n\x06suffix\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12!\n\x05regex\x18\x04 \x01(\tB\x10\x18\x01\xfa\x42\x05r\x03(\x80\x08\xb8\xee\xf2\xd2\x05\x01H\x00\x12@\n\nsafe_regex\x18\x05 \x01(\x0b\x32 .envoy.type.matcher.RegexMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x13\n\x0bignore_case\x18\x06 \x01(\x08\x42\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\"R\n\x11ListStringMatcher\x12=\n\x08patterns\x18\x01 \x03(\x0b\x32!.envoy.type.matcher.StringMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42t\n io.envoyproxy.envoy.type.matcherB\x0bStringProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.string_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\013StringProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _STRINGMATCHER.oneofs_by_name['match_pattern']._options = None
  _STRINGMATCHER.oneofs_by_name['match_pattern']._serialized_options = b'\370B\001'
  _STRINGMATCHER.fields_by_name['prefix']._options = None
  _STRINGMATCHER.fields_by_name['prefix']._serialized_options = b'\372B\004r\002\020\001'
  _STRINGMATCHER.fields_by_name['suffix']._options = None
  _STRINGMATCHER.fields_by_name['suffix']._serialized_options = b'\372B\004r\002\020\001'
  _STRINGMATCHER.fields_by_name['regex']._options = None
  _STRINGMATCHER.fields_by_name['regex']._serialized_options = b'\030\001\372B\005r\003(\200\010\270\356\362\322\005\001'
  _STRINGMATCHER.fields_by_name['safe_regex']._options = None
  _STRINGMATCHER.fields_by_name['safe_regex']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSTRINGMATCHER.fields_by_name['patterns']._options = None
  _LISTSTRINGMATCHER.fields_by_name['patterns']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_STRINGMATCHER']._serialized_start=181
  _globals['_STRINGMATCHER']._serialized_end=411
  _globals['_LISTSTRINGMATCHER']._serialized_start=413
  _globals['_LISTSTRINGMATCHER']._serialized_end=495
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v3/quic_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_protocol__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*envoy/config/listener/v3/quic_config.proto\x12\x18\x65nvoy.config.listener.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/protocol.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xda\x05\n\x13QuicProtocolOptions\x12H\n\x15quic_protocol_options\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.QuicProtocolOptions\x12/\n\x0cidle_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x18\x63rypto_handshake_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x07\x65nabled\x18\x04 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12X\n)packets_to_read_to_connection_count_ratio\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12H\n\x14\x63rypto_stream_config\x18\x06 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12G\n\x13proof_source_config\x18\x07 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12R\n\x1e\x63onnection_id_generator_config\x18\x08 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12]\n\x1fserver_preferred_address_config\x18\t \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01:0\x9a\xc5\x88\x1e+\n)envoy.api.v2.listener.QuicProtocolOptionsB\x8f\x01\n&io.envoyproxy.envoy.config.listener.v3B\x0fQuicConfigProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.listener.v3.quic_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.envoyproxy.envoy.config.listener.v3B\017QuicConfigProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\272\200\310\321\006\002\020\002'
  _QUICPROTOCOLOPTIONS.fields_by_name['packets_to_read_to_connection_count_ratio']._options = None
  _QUICPROTOCOLOPTIONS.fields_by_name['packets_to_read_to_connection_count_ratio']._serialized_options = b'\372B\004*\002(\001'
  _QUICPROTOCOLOPTIONS.fields_by_name['server_preferred_address_config']._options = None
  _QUICPROTOCOLOPTIONS.fields_by_name['server_preferred_address_config']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _QUICPROTOCOLOPTIONS._options = None
  _QUICPROTOCOLOPTIONS._serialized_options = b'\232\305\210\036+\n)envoy.api.v2.listener.QuicProtocolOptions'
  _globals['_QUICPROTOCOLOPTIONS']._serialized_start=369
  _globals['_QUICPROTOCOLOPTIONS']._serialized_end=1099
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/tracers/opentelemetry/resource_detectors/v3/dynatrace_resource_detector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^envoy/extensions/tracers/opentelemetry/resource_detectors/v3/dynatrace_resource_detector.proto\x12<envoy.extensions.tracers.opentelemetry.resource_detectors.v3\x1a\x1dudpa/annotations/status.proto\"!\n\x1f\x44ynatraceResourceDetectorConfigB\xf0\x01\nJio.envoyproxy.envoy.extensions.tracers.opentelemetry.resource_detectors.v3B\x1e\x44ynatraceResourceDetectorProtoP\x01Zxgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/resource_detectors/v3;resource_detectorsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.tracers.opentelemetry.resource_detectors.v3.dynatrace_resource_detector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nJio.envoyproxy.envoy.extensions.tracers.opentelemetry.resource_detectors.v3B\036DynatraceResourceDetectorProtoP\001Zxgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/resource_detectors/v3;resource_detectorsv3\272\200\310\321\006\002\020\002'
  _globals['_DYNATRACERESOURCEDETECTORCONFIG']._serialized_start=191
  _globals['_DYNATRACERESOURCEDETECTORCONFIG']._serialized_end=224
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/billing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import metric_pb2 as google_dot_api_dot_metric__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18google/api/billing.proto\x12\ngoogle.api\x1a\x17google/api/metric.proto\"\x93\x01\n\x07\x42illing\x12\x45\n\x15\x63onsumer_destinations\x18\x08 \x03(\x0b\x32&.google.api.Billing.BillingDestination\x1a\x41\n\x12\x42illingDestination\x12\x1a\n\x12monitored_resource\x18\x01 \x01(\t\x12\x0f\n\x07metrics\x18\x02 \x03(\tBn\n\x0e\x63om.google.apiB\x0c\x42illingProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.billing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\014BillingProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_BILLING']._serialized_start=66
  _globals['_BILLING']._serialized_end=213
  _globals['_BILLING_BILLINGDESTINATION']._serialized_start=148
  _globals['_BILLING_BILLINGDESTINATION']._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/path/rewrite/uri_template/v3/uri_template_rewrite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/path/rewrite/uri_template/v3/uri_template_rewrite.proto\x12-envoy.extensions.path.rewrite.uri_template.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"E\n\x18UriTemplateRewriteConfig\x12)\n\x15path_template_rewrite\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\x80\x02\x42\xc5\x01\n;io.envoyproxy.envoy.extensions.path.rewrite.uri_template.v3B\x17UriTemplateRewriteProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/path/rewrite/uri_template/v3;uri_templatev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.path.rewrite.uri_template.v3.uri_template_rewrite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.path.rewrite.uri_template.v3B\027UriTemplateRewriteProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/path/rewrite/uri_template/v3;uri_templatev3\272\200\310\321\006\002\020\002'
  _URITEMPLATEREWRITECONFIG.fields_by_name['path_template_rewrite']._options = None
  _URITEMPLATEREWRITECONFIG.fields_by_name['path_template_rewrite']._serialized_options = b'\372B\007r\005\020\001\030\200\002'
  _globals['_URITEMPLATEREWRITECONFIG']._serialized_start=179
  _globals['_URITEMPLATEREWRITECONFIG']._serialized_end=248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/grpc_http1_reverse_bridge/v2alpha1/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/config/filter/http/grpc_http1_reverse_bridge/v2alpha1/config.proto\x12;envoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"K\n\x0c\x46ilterConfig\x12\x1d\n\x0c\x63ontent_type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1c\n\x14withhold_grpc_frames\x18\x02 \x01(\x08\"(\n\x14\x46ilterConfigPerRoute\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x88\x02\nIio.envoyproxy.envoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1B\x0b\x43onfigProtoP\x01Zbgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/grpc_http1_reverse_bridge/v2alpha1\xf2\x98\xfe\x8f\x05<\x12:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nIio.envoyproxy.envoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1B\013ConfigProtoP\001Zbgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/grpc_http1_reverse_bridge/v2alpha1\362\230\376\217\005<\022:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3\272\200\310\321\006\002\020\001'
  _FILTERCONFIG.fields_by_name['content_type']._options = None
  _FILTERCONFIG.fields_by_name['content_type']._serialized_options = b'\372B\004r\002 \001'
  _globals['_FILTERCONFIG']._serialized_start=225
  _globals['_FILTERCONFIG']._serialized_end=300
  _globals['_FILTERCONFIGPERROUTE']._serialized_start=302
  _globals['_FILTERCONFIGPERROUTE']._serialized_end=342
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/ratelimit/v3/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import ratelimit_unit_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/common/ratelimit/v3/ratelimit.proto\x12$envoy.extensions.common.ratelimit.v3\x1a\"envoy/type/v3/ratelimit_unit.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd6\x03\n\x13RateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12Z\n\x05limit\x18\x02 \x01(\x0b\x32K.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride\x1an\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry\x1a\x64\n\x11RateLimitOverride\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12\x34\n\x04unit\x18\x02 \x01(\x0e\x32\x1c.envoy.type.v3.RateLimitUnitB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:1\x9a\xc5\x88\x1e,\n*envoy.api.v2.ratelimit.RateLimitDescriptor\"\xb2\x01\n\x18LocalRateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12:\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01*<\n\x1bXRateLimitHeadersRFCVersion\x12\x07\n\x03OFF\x10\x00\x12\x14\n\x10\x44RAFT_VERSION_03\x10\x01*<\n\x13VhRateLimitsOptions\x12\x0c\n\x08OVERRIDE\x10\x00\x12\x0b\n\x07INCLUDE\x10\x01\x12\n\n\x06IGNORE\x10\x02\x42\xa7\x01\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\x0eRatelimitProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/ratelimit/v3;ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\016RatelimitProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/ratelimit/v3;ratelimitv3\272\200\310\321\006\002\020\002'
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMITDESCRIPTOR_ENTRY._options = None
  _RATELIMITDESCRIPTOR_ENTRY._serialized_options = b'\232\305\210\0362\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry'
  _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit']._options = None
  _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
  _RATELIMITDESCRIPTOR.fields_by_name['entries']._serialized_options = b'\372B\005\222\001\002\010\001'
  _RATELIMITDESCRIPTOR._options = None
  _RATELIMITDESCRIPTOR._serialized_options = b'\232\305\210\036,\n*envoy.api.v2.ratelimit.RateLimitDescriptor'
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['entries']._serialized_options = b'\372B\005\222\001\002\010\001'
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket']._options = None
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_XRATELIMITHEADERSRFCVERSION']._serialized_start=909
  _globals['_XRATELIMITHEADERSRFCVERSION']._serialized_end=969
  _globals['_VHRATELIMITSOPTIONS']._serialized_start=971
  _globals['_VHRATELIMITSOPTIONS']._serialized_end=1031
  _globals['_RATELIMITDESCRIPTOR']._serialized_start=256
  _globals['_RATELIMITDESCRIPTOR']._serialized_end=726
  _globals['_RATELIMITDESCRIPTOR_ENTRY']._serialized_start=463
  _globals['_RATELIMITDESCRIPTOR_ENTRY']._serialized_end=573
  _globals['_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE']._serialized_start=575
  _globals['_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE']._serialized_end=675
  _globals['_LOCALRATELIMITDESCRIPTOR']._serialized_start=729
  _globals['_LOCALRATELIMITDESCRIPTOR']._serialized_end=907
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/agent/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-opencensus/proto/agent/common/v1/common.proto\x12 opencensus.proto.agent.common.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x02\n\x04Node\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.opencensus.proto.agent.common.v1.ProcessIdentifier\x12\x43\n\x0clibrary_info\x18\x02 \x01(\x0b\x32-.opencensus.proto.agent.common.v1.LibraryInfo\x12\x43\n\x0cservice_info\x18\x03 \x01(\x0b\x32-.opencensus.proto.agent.common.v1.ServiceInfo\x12J\n\nattributes\x18\x04 \x03(\x0b\x32\x36.opencensus.proto.agent.common.v1.Node.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x11ProcessIdentifier\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa7\x02\n\x0bLibraryInfo\x12H\n\x08language\x18\x01 \x01(\x0e\x32\x36.opencensus.proto.agent.common.v1.LibraryInfo.Language\x12\x18\n\x10\x65xporter_version\x18\x02 \x01(\t\x12\x1c\n\x14\x63ore_library_version\x18\x03 \x01(\t\"\x95\x01\n\x08Language\x12\x18\n\x14LANGUAGE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x43PP\x10\x01\x12\x0b\n\x07\x43_SHARP\x10\x02\x12\n\n\x06\x45RLANG\x10\x03\x12\x0b\n\x07GO_LANG\x10\x04\x12\x08\n\x04JAVA\x10\x05\x12\x0b\n\x07NODE_JS\x10\x06\x12\x07\n\x03PHP\x10\x07\x12\n\n\x06PYTHON\x10\x08\x12\x08\n\x04RUBY\x10\t\x12\n\n\x06WEB_JS\x10\n\"\x1b\n\x0bServiceInfo\x12\x0c\n\x04name\x18\x01 \x01(\tB\xa2\x01\n#io.opencensus.proto.agent.common.v1B\x0b\x43ommonProtoP\x01ZIgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/common/v1\xea\x02 OpenCensus.Proto.Agent.Common.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opencensus.proto.agent.common.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.opencensus.proto.agent.common.v1B\013CommonProtoP\001ZIgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/common/v1\352\002 OpenCensus.Proto.Agent.Common.V1'
  _NODE_ATTRIBUTESENTRY._options = None
  _NODE_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _globals['_NODE']._serialized_start=117
  _globals['_NODE']._serialized_end=461
  _globals['_NODE_ATTRIBUTESENTRY']._serialized_start=412
  _globals['_NODE_ATTRIBUTESENTRY']._serialized_end=461
  _globals['_PROCESSIDENTIFIER']._serialized_start=463
  _globals['_PROCESSIDENTIFIER']._serialized_end=567
  _globals['_LIBRARYINFO']._serialized_start=570
  _globals['_LIBRARYINFO']._serialized_end=865
  _globals['_LIBRARYINFO_LANGUAGE']._serialized_start=716
  _globals['_LIBRARYINFO_LANGUAGE']._serialized_end=865
  _globals['_SERVICEINFO']._serialized_start=867
  _globals['_SERVICEINFO']._serialized_end=894
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/filters/network/dubbo_proxy/router/v3/router.proto\x12\x36\x65nvoy.extensions.filters.network.dubbo_proxy.router.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"A\n\x06Router:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.dubbo.router.v2alpha1.RouterB\xc5\x01\nDio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.router.v3B\x0bRouterProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/dubbo_proxy/router/v3;routerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.dubbo_proxy.router.v3.router_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.router.v3B\013RouterProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/dubbo_proxy/router/v3;routerv3\272\200\310\321\006\002\020\002'
  _ROUTER._options = None
  _ROUTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.dubbo.router.v2alpha1.Router'
  _globals['_ROUTER']._serialized_start=193
  _globals['_ROUTER']._serialized_end=258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/data/orca/v1/orca_load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(udpa/data/orca/v1/orca_load_report.proto\x12\x11udpa.data.orca.v1\x1a\x17validate/validate.proto\"\x9a\x03\n\x0eOrcaLoadReport\x12\x30\n\x0f\x63pu_utilization\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x30\n\x0fmem_utilization\x18\x02 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x12\x0b\n\x03rps\x18\x03 \x01(\x04\x12H\n\x0crequest_cost\x18\x04 \x03(\x0b\x32\x32.udpa.data.orca.v1.OrcaLoadReport.RequestCostEntry\x12\x65\n\x0butilization\x18\x05 \x03(\x0b\x32\x32.udpa.data.orca.v1.OrcaLoadReport.UtilizationEntryB\x1c\xfa\x42\x19\x9a\x01\x16*\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\x1a\x32\n\x10RequestCostEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x32\n\x10UtilizationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x42\x64\n!com.github.udpa.udpa.data.orca.v1B\x13OrcaLoadReportProtoP\x01Z(github.com/cncf/xds/go/udpa/data/orca/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'udpa.data.orca.v1.orca_load_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.github.udpa.udpa.data.orca.v1B\023OrcaLoadReportProtoP\001Z(github.com/cncf/xds/go/udpa/data/orca/v1'
  _ORCALOADREPORT_REQUESTCOSTENTRY._options = None
  _ORCALOADREPORT_REQUESTCOSTENTRY._serialized_options = b'8\001'
  _ORCALOADREPORT_UTILIZATIONENTRY._options = None
  _ORCALOADREPORT_UTILIZATIONENTRY._serialized_options = b'8\001'
  _ORCALOADREPORT.fields_by_name['cpu_utilization']._options = None
  _ORCALOADREPORT.fields_by_name['cpu_utilization']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['mem_utilization']._options = None
  _ORCALOADREPORT.fields_by_name['mem_utilization']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _ORCALOADREPORT.fields_by_name['utilization']._options = None
  _ORCALOADREPORT.fields_by_name['utilization']._serialized_options = b'\372B\031\232\001\026*\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000'
  _globals['_ORCALOADREPORT']._serialized_start=89
  _globals['_ORCALOADREPORT']._serialized_end=499
  _globals['_ORCALOADREPORT_REQUESTCOSTENTRY']._serialized_start=397
  _globals['_ORCALOADREPORT_REQUESTCOSTENTRY']._serialized_end=447
  _globals['_ORCALOADREPORT_UTILIZATIONENTRY']._serialized_start=449
  _globals['_ORCALOADREPORT_UTILIZATIONENTRY']._serialized_end=499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/file/v3/file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/access_loggers/file/v3/file.proto\x12\'envoy.extensions.access_loggers.file.v3\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xda\x02\n\rFileAccessLog\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x06\x66ormat\x18\x02 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12;\n\x0bjson_format\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x41\n\x11typed_json_format\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12N\n\nlog_format\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.accesslog.v2.FileAccessLogB\x13\n\x11\x61\x63\x63\x65ss_log_formatB\xa3\x01\n5io.envoyproxy.envoy.extensions.access_loggers.file.v3B\tFileProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/file/v3;filev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.file.v3.file_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.access_loggers.file.v3B\tFileProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/file/v3;filev3\272\200\310\321\006\002\020\002'
  _FILEACCESSLOG.fields_by_name['path']._options = None
  _FILEACCESSLOG.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _FILEACCESSLOG.fields_by_name['format']._options = None
  _FILEACCESSLOG.fields_by_name['format']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _FILEACCESSLOG.fields_by_name['json_format']._options = None
  _FILEACCESSLOG.fields_by_name['json_format']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _FILEACCESSLOG.fields_by_name['typed_json_format']._options = None
  _FILEACCESSLOG.fields_by_name['typed_json_format']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _FILEACCESSLOG.fields_by_name['log_format']._options = None
  _FILEACCESSLOG.fields_by_name['log_format']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FILEACCESSLOG._options = None
  _FILEACCESSLOG._serialized_options = b'\232\305\210\036)\n\'envoy.config.accesslog.v2.FileAccessLog'
  _globals['_FILEACCESSLOG']._serialized_start=309
  _globals['_FILEACCESSLOG']._serialized_end=655
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.data.tap.v2alpha import common_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/data/tap/v2alpha/transport.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a#envoy/data/tap/v2alpha/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"s\n\nConnection\x12\x31\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x32\n\x0eremote_address\x18\x03 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\"\x89\x03\n\x0bSocketEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x04read\x18\x02 \x01(\x0b\x32(.envoy.data.tap.v2alpha.SocketEvent.ReadH\x00\x12:\n\x05write\x18\x03 \x01(\x0b\x32).envoy.data.tap.v2alpha.SocketEvent.WriteH\x00\x12<\n\x06\x63losed\x18\x04 \x01(\x0b\x32*.envoy.data.tap.v2alpha.SocketEvent.ClosedH\x00\x1a\x32\n\x04Read\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x1aG\n\x05Write\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x12\x12\n\nend_stream\x18\x02 \x01(\x08\x1a\x08\n\x06\x43losedB\x10\n\x0e\x65vent_selector\"\xc5\x01\n\x13SocketBufferedTrace\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x36\n\nconnection\x18\x02 \x01(\x0b\x32\".envoy.data.tap.v2alpha.Connection\x12\x33\n\x06\x65vents\x18\x03 \x03(\x0b\x32#.envoy.data.tap.v2alpha.SocketEvent\x12\x16\n\x0eread_truncated\x18\x04 \x01(\x08\x12\x17\n\x0fwrite_truncated\x18\x05 \x01(\x08\"\xaf\x01\n\x1aSocketStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x38\n\nconnection\x18\x02 \x01(\x0b\x32\".envoy.data.tap.v2alpha.ConnectionH\x00\x12\x34\n\x05\x65vent\x18\x03 \x01(\x0b\x32#.envoy.data.tap.v2alpha.SocketEventH\x00\x42\x0f\n\rmessage_pieceB\x7f\n$io.envoyproxy.envoy.data.tap.v2alphaB\x0eTransportProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v2alpha.transport_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\016TransportProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_CONNECTION']._serialized_start=200
  _globals['_CONNECTION']._serialized_end=315
  _globals['_SOCKETEVENT']._serialized_start=318
  _globals['_SOCKETEVENT']._serialized_end=711
  _globals['_SOCKETEVENT_READ']._serialized_start=560
  _globals['_SOCKETEVENT_READ']._serialized_end=610
  _globals['_SOCKETEVENT_WRITE']._serialized_start=612
  _globals['_SOCKETEVENT_WRITE']._serialized_end=683
  _globals['_SOCKETEVENT_CLOSED']._serialized_start=685
  _globals['_SOCKETEVENT_CLOSED']._serialized_end=693
  _globals['_SOCKETBUFFEREDTRACE']._serialized_start=714
  _globals['_SOCKETBUFFEREDTRACE']._serialized_end=911
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_start=914
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_end=1089
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/connection_limit/v3/connection_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKenvoy/extensions/filters/network/connection_limit/v3/connection_limit.proto\x12\x34\x65nvoy.extensions.filters.network.connection_limit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdc\x01\n\x0f\x43onnectionLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12>\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02(\x01\x12(\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x0fruntime_enabled\x18\x04 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlagB\xd4\x01\nBio.envoyproxy.envoy.extensions.filters.network.connection_limit.v3B\x14\x43onnectionLimitProtoP\x01Zngithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/connection_limit/v3;connection_limitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.connection_limit.v3.connection_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.filters.network.connection_limit.v3B\024ConnectionLimitProtoP\001Zngithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/connection_limit/v3;connection_limitv3\272\200\310\321\006\002\020\002'
  _CONNECTIONLIMIT.fields_by_name['stat_prefix']._options = None
  _CONNECTIONLIMIT.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _CONNECTIONLIMIT.fields_by_name['max_connections']._options = None
  _CONNECTIONLIMIT.fields_by_name['max_connections']._serialized_options = b'\372B\0042\002(\001'
  _globals['_CONNECTIONLIMIT']._serialized_start=287
  _globals['_CONNECTIONLIMIT']._serialized_end=507
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/least_request/v3/least_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.load_balancing_policies.common.v3 import common_pb2 as envoy_dot_extensions_dot_load__balancing__policies_dot_common_dot_v3_dot_common__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMenvoy/extensions/load_balancing_policies/least_request/v3/least_request.proto\x12\x39\x65nvoy.extensions.load_balancing_policies.least_request.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a?envoy/extensions/load_balancing_policies/common/v3/common.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x85\x03\n\x0cLeastRequest\x12;\n\x0c\x63hoice_count\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x02\x12@\n\x13\x61\x63tive_request_bias\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeDouble\x12^\n\x11slow_start_config\x18\x03 \x01(\x0b\x32\x43.envoy.extensions.load_balancing_policies.common.v3.SlowStartConfig\x12`\n\x12locality_lb_config\x18\x04 \x01(\x0b\x32\x44.envoy.extensions.load_balancing_policies.common.v3.LocalityLbConfig\x12\x34\n\x10\x65nable_full_scan\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xd8\x01\nGio.envoyproxy.envoy.extensions.load_balancing_policies.least_request.v3B\x11LeastRequestProtoP\x01Zpgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/least_request/v3;least_requestv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.least_request.v3.least_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nGio.envoyproxy.envoy.extensions.load_balancing_policies.least_request.v3B\021LeastRequestProtoP\001Zpgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/least_request/v3;least_requestv3\272\200\310\321\006\002\020\002'
  _LEASTREQUEST.fields_by_name['choice_count']._options = None
  _LEASTREQUEST.fields_by_name['choice_count']._serialized_options = b'\372B\004*\002(\002'
  _globals['_LEASTREQUEST']._serialized_start=327
  _globals['_LEASTREQUEST']._serialized_end=716
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/mongo_proxy/v3/mongo_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.common.fault.v3 import fault_pb2 as envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/extensions/filters/network/mongo_proxy/v3/mongo_proxy.proto\x12/envoy.extensions.filters.network.mongo_proxy.v3\x1a\x34\x65nvoy/extensions/filters/common/fault/v3/fault.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf2\x01\n\nMongoProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\naccess_log\x18\x02 \x01(\t\x12\x43\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x34.envoy.extensions.filters.common.fault.v3.FaultDelay\x12\x1d\n\x15\x65mit_dynamic_metadata\x18\x04 \x01(\x08\x12\x10\n\x08\x63ommands\x18\x05 \x03(\t:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.network.mongo_proxy.v2.MongoProxyB\xc0\x01\n=io.envoyproxy.envoy.extensions.filters.network.mongo_proxy.v3B\x0fMongoProxyProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/mongo_proxy/v3;mongo_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.mongo_proxy.v3.mongo_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.filters.network.mongo_proxy.v3B\017MongoProxyProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/mongo_proxy/v3;mongo_proxyv3\272\200\310\321\006\002\020\002'
  _MONGOPROXY.fields_by_name['stat_prefix']._options = None
  _MONGOPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _MONGOPROXY._options = None
  _MONGOPROXY._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.network.mongo_proxy.v2.MongoProxy'
  _globals['_MONGOPROXY']._serialized_start=264
  _globals['_MONGOPROXY']._serialized_end=506
# @@protoc_insertion_point(module_scope)
